#
# spec file for package python-pytest-randomly
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-randomly
Version:        3.16.0
Release:        1.2
Summary:        Pytest plugin to randomly order tests and control random.seed
License:        MIT
URL:            https://github.com/pytest-dev/pytest-randomly
Source:         https://github.com/pytest-dev/pytest-randomly/archive/%{version}.tar.gz#/pytest-randomly-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-importlib-metadata >= 3.6.0
Requires:       python-pytest
Recommends:     python-Faker >= 13.11.0
Suggests:       python-numpy
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Faker >= 13.11.0}
BuildRequires:  %{python_module factory_boy}
BuildRequires:  %{python_module importlib-metadata >= 3.6.0}
# Django package not available on SLFO:Main
%if 0%{suse_version} > 1600
BuildRequires:  %{python_module model-bakery >= 1.13.0}
%endif
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Pytest plugin to randomly order tests and control random.seed.

Features:
   * Randomly shuffles the order of test items. This is done first at
     the level of modules, then at the level of test classes (if you
     have them), then at the order of functions. This also works with
     things like doctests.
   * Resets random.seed() at the start of every test case and test to
     fixed number - this defaults to time.time() from the start of
     your test run, but you can pass in --randomly-seed to repeat a
     randomness-induced failure.
   * If factory boy is installed, its random state is reset at the
     start of every test. This allows for repeatable use of its random
     'fuzzy' features.
   * If faker is installed, its random state is reset at the start of
     every test. This is also for repeatable fuzzy data in tests.
   * If numpy is installed, its random state is reset at the start of
     every test.

%prep
%autosetup -p1 -n pytest-randomly-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_entrypoint_injection needs installed module for pytest to use
skiptest="test_entrypoint_injection or test_it_runs_before_stepwise"

# Django package not available on SLFO:Main
%if 0%{suse_version} <= 1600
skiptest+=" or test_model_bakery"
%endif

%pytest -k "not ($skiptest)"

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/pytest_randomly
%{python_sitelib}/pytest_randomly-%{version}*-info

%changelog
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 3.16.0:
  * Drop Python 3.8 support.
  * Support Python 3.13.
* Mon Oct 28 2024 Daniel Garcia <daniel.garcia@suse.com>
- Make model-bakery BuildRequires optional, in SLFO:Main we don't have
  python311-django.
* Tue Nov  7 2023 Dirk Müller <dmueller@suse.com>
- update to 3.15.0:
  * Support Python 3.12.
  * Reset the random state for `Model Bakery`
* Mon Jul 24 2023 Dirk Müller <dmueller@suse.com>
- update to 3.13.0:
  * Drop Python 3.7 support.
- drop fix-tests-pytest-73.patch (upstream)
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 3.12.0:
  * Support Python 3.11.
  * Drop Python 3.6 support.
  * Work on FIPS Python 3.9+, by declaring use of
    ``hashlib.md5()`` as not used for security.
  * Fix crash when pytest’s cacheprovider is disabled.
  * Improve group name in ``pytest --help``.
  * Fix new shuffling to work when one or more test in a class or
    module have the same test id.
  * Rework shuffling algorithm to use hashing. This means that
    running a subset of tests with the same seed will now produce
    the same ordering as running the full set of tests.
    This allows narrowing down ordering-related failures.
  * Add type hints.
  * Support Python 3.10.
- add fix-tests-pytest-73.patch to support pytest 7.3.x
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Mar 24 2023 Matej Cepl <mcepl@suse.com>
- Rebuild in SP4.
* Sat Apr 17 2021 Ben Greiner <code@bnavigator.de>
- Update to 3.7.0
  * Drop dependency on backports.entry-points-selectable by
    depending on importlib-metadata version 3.6.0+.
- Release 3.6.0
  * Fix deprecation warning from importlib-metadata 3.9.0+.
  * Stop distributing tests to reduce package size. Tests are not
    intended to be run outside of the tox setup in the repository.
    Repackagers can use GitHub's tarballs per tag.
  * Drop Python 3.5 support.
- Release 3.5.0
  * Support Python 3.9.
  * Move license from BSD to MIT License
- Drop pytest6.patch merged upstream
- Don't try test with non-existent python36-numpy
* Tue Aug 25 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.4.1
  * Fix numpy error ``ValueError: Seed must be between 0 and 2**32 - 1`` when
    passed a seed outside of this range.
- Add upstream patch pytest6.patch to fix tests
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.4.0:
  * Provide a faker_seed fixture to set the seed for tests using faker's pytest fixtures (as per its docs).
* Mon Apr 27 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.1:
  * Fix to work when pytest-xdist is not installed or active.
  * Add pytest-xdist support.
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.1:
  * Update MANIFEST.in so tests are included in the sdist tarball again.
* Mon Jan  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.0:
  * Converted setuptools metadata to configuration file
  * Convert reading entrypoints to use importlib.metadata.
    Depend on importlib-metadata on Python < 3.8.
  * Update Python support to 3.5-3.8.
* Mon Sep  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.0:
  * Add plugins via entry points pytest_randomly.random_seeder to allow
    outside packages to register additional random generators to seed.
    This has added a dependency on the entrypoints package.
- Drop patch tests-restore-python2.7.patch
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.0:
  * Handle CollectErrors and ImportErrors during collection when accessing item.module.
* Tue Mar 26 2019 John Vandenberg <jayvdb@gmail.com>
- Downgrade Faker dependency to Recommends
- Add Suggests for numpy
- Add tests-restore-python2.7.patch to re-add support for Python 2.7
- Use PYTHONDONTWRITEBYTECODE=true to fix file-contains-buildroot
  on Leap 42.3
- Update to v2.1.1
  * Fix including tests in sdist after re-arrangement in 2.1.0
- from v2.1.0
  * Add the option --randomly-seed=last to reuse the last used value
    for the seed
- from v2.0.0
  * Drop Python 2 support, only Python 3.4+ is supported now
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Make sure we execute tests
* Mon Jan 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version for v1.2.3
